==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-drools/drools-decisiontables/src/test/java/org/drools/decisiontable/parser/csv/CsvLineParserTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.drools.decisiontable.parser.csv;

import java.util.List;

import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThat;

public class CsvLineParserTest {

    @Test
    public void testSimpleLineParse() {
        final CsvLineParser parser = new CsvLineParser();
        final String s = "a,b,c";
        final List<String> list = parser.parse(s);
        
        assertThat(list).hasSize(3).containsExactly("a", "b", "c");
    }

    @Test
    public void testLineParse() {
        final CsvLineParser parser = new CsvLineParser();
        final String s = "a,\"b\",c";
        final List<String> list = parser.parse(s);
        
        assertThat(list).hasSize(3).containsExactly("a", "b", "c");
    }

    @Test
    public void testDoubleQuotes() {
        final CsvLineParser parser = new CsvLineParser();
        final String s = "a,\"\"\"b\"\"\",c";
        final List<String> list = parser.parse(s);
        
        assertThat(list).hasSize(3).containsExactly("a", "\"b\"", "c");
    }

}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-drools/drools-decisiontables/src/test/java/org/drools/decisiontable/parser/csv/CsvLineParserTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.drools.decisiontable.parser.csv;

import java.util.List;

import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

public class CsvLineParserTest {

    @Test
    public void testSimpleLineParse() {
        final CsvLineParser parser = new CsvLineParser();
        final String s = "a,b,c";
        final List<String> list = parser.parse(s);
        
        assertThat(list).hasSize(3).containsExactly("a", "b", "c");
    }

    @Test
    public void testLineParse() {
        final CsvLineParser parser = new CsvLineParser();
        final String s = "a,\"b\",c";
        final List<String> list = parser.parse(s);
        
        assertThat(list).hasSize(3).containsExactly("a", "b", "c");
    }

    @Test
    public void testDoubleQuotes() {
        final CsvLineParser parser = new CsvLineParser();
        final String s = "a,\"\"\"b\"\"\",c";
        final List<String> list = parser.parse(s);
        
        assertThat(list).hasSize(3).containsExactly("a", "\"b\"", "c");
    }

}
